@@ -43,7 +43,7 @@ package Astro::Coord::ECI::Moon;
 use strict;
 use warnings;
 
-our $VERSION = '0.042';
+our $VERSION = '0.043';
 
 use base qw{Astro::Coord::ECI};
 
@@ -60,10 +60,10 @@ my %terms;
 my $where;
 while (<DATA>) {
     chomp;
-    s/^\s+//;
-    s/\s+$//;
+    s/ \A \s+ //smx;
+    s/ \s+ \z //smx;
     next unless $_;
-    next if m/^#/;
+    next if m/ \A \s* [#] /smx;
     s/^-// and do {
 	last if $_ eq 'end';
 	$where = $terms{$_} ||= [];
@@ -228,6 +228,19 @@ sub almanac_hash {
     }, almanac(@_);
 }
 
+=item $elevation = $tle->correct_for_refraction( $elevation )
+
+This override of the superclass' method simply returns the elevation
+passed to it. Since the Moon has no atmosphere to speak of, there should
+be no diffraction to speak of either.
+
+=cut
+
+sub correct_for_refraction {
+    my ( $self, $elevation ) = @_;
+    return $elevation;
+}
+
 
 =item ($time, $quarter, $desc) = $moon->next_quarter ($want);
 
@@ -670,3 +683,5 @@ __DATA__
 1  0 -1 -1	     -119
 4 -1  0 -1	      115
 2 -2  0  1	      107
+
+# ex: set textwidth=72 :
